@@ -7,17 +7,17 @@ from modules.color import print_colored, colors, bcolors
 from modules.banners import print_banner
 from modules.searchvuln import SearchSploits
 from modules.scanner import AnalyseScanResults, PortScan, DiscoverHosts
-from modules.outfile import InitializeOutput, output
+from modules.outfile import InitializeOutput, WriteToFile, OutputBanner
 
 __author__ = 'GamehunterKaan'
-__version__ = '1.0.1'
+__version__ = '1.0.3'
 
 #parse command line arguments
 argparser = ArgumentParser(description="AutoPWN Suite")
 argparser.add_argument("-o", "--output", help="Output file name. (Default : autopwn.log)", default="autopwn.log")
 argparser.add_argument("-t", "--target", help="Target range to scan. This argument overwrites the hostfile argument. (192.168.0.1 or 192.168.0.0/24)")
 argparser.add_argument("-hf", "--hostfile", help="File containing a list of hosts to scan.")
-argparser.add_argument("-st", "--scantype", help="Scan type. (Ping or ARP)", default="arp")
+argparser.add_argument("-st", "--scantype", help="Scan type. (Ping or ARP)")
 argparser.add_argument("-s", "--speed", help="Scan speed. (0-5) (Default : 3)", default=3)
 argparser.add_argument("-a", "--api", help="Specify API key for vulnerability detection for faster scanning. You can also specify your API key in api.txt file. (Default : None)", default=None)
 argparser.add_argument("-y", "--yesplease", help="Don't ask for anything. (Full automatic mode)",action="store_true")
@@ -36,15 +36,33 @@ outputfile = args.output
 InitializeOutput(context=args.output)
 DontAskForConfirmation = args.yesplease
 
-scantype = args.scantype
-scanspeed = int(args.speed)
-
 def is_root():
     if getuid() == 0:
         return True #return True if the user is root
     else:
         return False
 
+if args.scantype == "arp":
+    if not is_root():
+        print_colored("You must be root to do an arp scan!", colors.red)
+        scantype = "ping"
+elif args.scantype == "ping":
+    pass
+elif args.scantype == "":
+    if is_root():
+        scantype = "arp"
+    else:
+        scantype = "ping"
+else:
+    if is_root():
+        scantype = "arp"
+        print_colored("Unknown scan type: %s! Using arp scan instead..." % (args.scantype), colors.red)
+    else:
+        scantype = "ping"
+        print_colored("Unknown scan type: %s! Using ping scan instead..." % (args.scantype), colors.red)
+
+scanspeed = int(args.speed)
+
 if is_root() == False:
     print_colored("It's recommended to run this script as root since it's more silent and accurate.", colors.red)
 
@@ -79,6 +97,7 @@ else:
 def check_nmap():
     # Check if nmap is installed
     # If not, install it
+    # also add a function to install nmap on windows
     try:
         nmap_checker = check_call(["nmap", "-h"], stdout=DEVNULL, stderr=DEVNULL)
     except FileNotFoundError:
@@ -141,13 +160,12 @@ elif args.mode.lower() == "noise":
     print_colored("Noise mode enabled!", colors.yellow)
 elif args.mode.lower() == "normal":
     scanmode = "normal"
-    print_colored("Normal mode enabled!", colors.yellow)
 else:
     print_colored("Invalid mode specified! %s" % (args.mode), colors.red)
     print_colored("Using default mode : normal", colors.cyan)
     scanmode = "normal"
 
-output.OutputBanner(targetarg, scantype, scanspeed, args.hostfile)
+OutputBanner(targetarg, scantype, scanspeed, args.hostfile)
 
 #ask the user if they want to scan ports
 def UserWantsPortScan():
@@ -161,7 +179,7 @@ def UserWantsPortScan():
                 return True
                 break
             elif wannaportscan == 'n' or wannaportscan == 'no':
-                output.WriteToFile("User refused to run a port scan on these hosts.")
+                WriteToFile("User refused to run a port scan on these hosts.")
                 return False
             else:
                 print("Please say Y or N!")
@@ -178,7 +196,7 @@ def UserWantsVulnerabilityDetection():
                 return True
                 break
             elif wannavulnscan == 'n' or wannavulnscan == 'no':
-                output.WriteToFile("User refused to do a version based vulnerability detection.")
+                WriteToFile("User refused to do a version based vulnerability detection.")
                 return False
             else:
                 print("Please say Y or N!")
@@ -186,11 +204,11 @@ def UserWantsVulnerabilityDetection():
 #post scan stuff
 def FurtherEnumuration(hosts):
     for host in hosts:
-        print("\t\t" + host)
-        output.WriteToFile("\t\t" + host)
+        print(host.center(60))
+        WriteToFile(host.center(60))
     if UserWantsPortScan():
         for host in hosts:
-            output.WriteToFile("\n" + "-" * 50)
+            WriteToFile("\n" + "-" * 60)
             PortScanResults = PortScan(host, scanspeed, scanmode)
             PortArray = AnalyseScanResults(PortScanResults,host)
             if len(PortArray) > 0:
@@ -198,8 +216,8 @@ def FurtherEnumuration(hosts):
                     SearchSploits(PortArray, apiKey)
             else:
                 print("Skipping vulnerability detection for " + str(host))
-                output.WriteToFile("Skipped vulnerability detection for " + str(host))
-            output.WriteToFile("\n" + "-" * 50)
+                WriteToFile("Skipped vulnerability detection for " + str(host))
+            WriteToFile("\n" + "-" * 60)
 
 #main function
 def main():
@@ -213,4 +231,4 @@ if __name__ == '__main__':
         main()
     except KeyboardInterrupt:
         print_colored("Ctrl+C pressed. Exiting.", colors.red)
-        output.WriteToFile("Ctrl+C pressed. Exiting.")
+        WriteToFile("Ctrl+C pressed. Exiting.")
