@@ -1,10 +1,19 @@
-from modules.nmap import PortScanner, PortScannerAsync
+from modules.nmap import PortScanner
 from modules.color import print_colored, colors, bcolors
-from modules.outfile import output
+from modules.outfile import WriteToFile
 from os import getuid
-from subprocess import Popen
-from time import sleep
 from multiprocessing import Process
+from dataclasses import dataclass
+
+@dataclass
+class PortInfo:
+    # gotta figure out how to use dataclasses
+    port = 0
+    protocol = ''
+    state = ''
+    service = ''
+    product = ''
+    version = ''
 
 def is_root():
     if getuid() == 0:
@@ -42,9 +51,9 @@ def TestArp(target, mode):
 #run a port scan on target using nmap
 def PortScan(target, scanspeed, mode):
     print_colored("\n" + "-" * 60, colors.green)
-    print_colored("\tRunning a portscan on host " + str(target) + "...", colors.green)
+    print_colored(("Running a portscan on host " + str(target) + "...").center(60), colors.green)
     print_colored("-" * 60 + "\n", colors.green)
-    output.WriteToFile("\nPortscan on " + str(target) + " : ")
+    WriteToFile("\nPortscan on " + str(target) + " : ")
     nm = PortScanner()
     if is_root():
         if mode == "evade":
@@ -70,9 +79,9 @@ def CreateNoise(target):
 def DiscoverHosts(target, scantype, scanspeed, mode):
     if mode == "noise":
         print_colored("\n" + "-" * 60, colors.green)
-        print_colored("\tCreating noise...", colors.green)
+        print_colored("Creating noise...".center(60), colors.green)
         print_colored("-" * 60 + "\n", colors.green)
-        output.WriteToFile("\nCreating noise...")
+        WriteToFile("\nCreating noise...")
         if scantype == "ping":
             Uphosts = TestPing(target, mode)
         elif scantype == "arp":
@@ -89,34 +98,18 @@ def DiscoverHosts(target, scantype, scanspeed, mode):
                 sleep(10)
             except KeyboardInterrupt:
                 print_colored("\nStopping noise...", colors.red)
-                output.WriteToFile("\nStopped noise...")
+                WriteToFile("\nStopped noise...")
                 exit(0)
     else:
-        if scantype == "arp":
-            if not is_root():
-                print_colored("You must be root to do an arp scan!", colors.red)
-                scantype = "ping"
-        elif scantype == "ping":
-            pass
-        else:
-            if is_root():
-                print_colored("Unknown scan type: %s! Using arp scan instead..." % (scantype), colors.red)
-                scantype = "arp"
-            else:
-                print_colored("Unknown scan type: %s! Using ping scan instead..." % (scantype), colors.red)
-                scantype = "ping"
-
         print_colored("\n" + "-" * 60, colors.green)
         if type(target) is list:
-            print_colored("\tScanning %d hosts using %s scan..." % (len(target), scantype), colors.green)
+            print_colored(("Scanning " + str(len(target)) + " target(s) using " + scantype + " scan...").center(60), colors.green)
+            WriteToFile("\nScanning %d hosts using %s scan..." % (len(target), scantype))
         else:
-            print_colored("\tScanning %s using %s scan..." % (target, scantype), colors.green)
+            print_colored(("Scanning " + target + " using " + scantype + " scan...").center(60), colors.green)
+            WriteToFile("\nScanning %s using %s scan..." % (target, scantype))
+        
         print_colored("-" * 60 + "\n", colors.green)
-
-        if type(target) is list:
-            output.WriteToFile("\nScanning %d hosts using %s scan..." % (len(target), scantype))
-        else:
-            output.WriteToFile("\nScanning %s using %s scan..." % (target, scantype))
         
         if scantype == "ping":
             OnlineHosts = TestPing(target, mode)
@@ -129,6 +122,7 @@ def DiscoverHosts(target, scantype, scanspeed, mode):
 #analyse and print scan results
 def AnalyseScanResults(nm,target):
     HostArray = []
+
     try:
         nm[target]
 
@@ -157,18 +151,45 @@ def AnalyseScanResults(nm,target):
         except:
             ostype = 'Unknown'
 
-        print_colored("MAC Address : %s\tVendor : %s" % (mac, vendor), colors.yellow)
-        print_colored("OS : %s\tAccuracy : %s\tType : %s\n" % (os, accuracy,ostype), colors.yellow)
+        print(
+            (
+                bcolors.yellow + "MAC Address : " + bcolors.endc + "{0:20}" +
+                bcolors.yellow + " Vendor : " + bcolors.endc + "{1:30}"
+            ).format(mac , vendor)
+        )
 
-        output.WriteToFile("MAC Address : %s\tVendor : %s" % (mac, vendor))
-        output.WriteToFile("OS : %s\tAccuracy : %s\tType : %s\n" % (os, accuracy,ostype))
+        WriteToFile(
+            (
+                "MAC Address : {0:20}" +
+                " Vendor : {1:30}\n"
+            ).format(mac, vendor)
+        )
+
+        print(
+            (
+                bcolors.yellow + "OS : " + bcolors.endc + "{0:20}" +
+                bcolors.yellow + " Accuracy : " + bcolors.endc + "{1:5}" +
+                bcolors.yellow + " Type : " + bcolors.endc + "{2:20}"
+            ).format(os , accuracy , ostype)
+        )
+
+        WriteToFile(
+            (
+                "OS : {0:20}" +
+                " Accuracy : {1:5}" +
+                " Type : {2:20}"
+            ).format(os , accuracy , ostype)
+        )
+
+        print("\n")
+        WriteToFile("\n")
 
         if nm[target]['status']['reason'] == 'localhost-response' or nm[target]['status']['reason'] == 'user-set':
             print_colored('Target ' + str(target) + ' seems to be us.', colors.underline)
-            output.WriteToFile('Target ' + str(target) + ' seems to be us.')
+            WriteToFile('Target ' + str(target) + ' seems to be us.')
         if len(nm[target].all_protocols()) == 0:
             print_colored("Target " + str(target) + " seems to have no open ports.", colors.red)
-            output.WriteToFile("Target " + str(target) + " seems to have no open ports.")
+            WriteToFile("Target " + str(target) + " seems to have no open ports.")
         for proto in nm[target].all_protocols():
             for port in nm[target][proto].keys():
                                 
@@ -208,27 +229,32 @@ def AnalyseScanResults(nm,target):
                 print(
                     (
                         bcolors.cyan + "Port : " + bcolors.endc + "{0:10}" + 
-                        bcolors.cyan + "State : " + bcolors.endc + "{1:10}" +
-                        bcolors.cyan + "Service : " + bcolors.endc + "{2:15}" +
-                        bcolors.cyan + "Product : " + bcolors.endc + "{3:20}" +
-                        bcolors.cyan + "Version : " + bcolors.endc + "{4:15}"
+                        bcolors.cyan + " State : " + bcolors.endc + "{1:10}" +
+                        bcolors.cyan + " Service : " + bcolors.endc + "{2:15}" +
+                        bcolors.cyan + " Product : " + bcolors.endc + "{3:20}" +
+                        bcolors.cyan + " Version : " + bcolors.endc + "{4:15}"
                     ).format(str(port), state, service, product, version)
                 )
 
-                output.WriteToFile(
+                WriteToFile(
                     (
-                        "Port : " + "{0:10}" + 
-                        "State : " + "{1:10}" +
-                        "Service : " + "{2:20}" +
-                        "Product : " + "{3:20}" +
-                        "Version : " + "{4:20}"
+                        "Port : {0:10}" + 
+                        " State : {1:10}" +
+                        " Service : {2:20}" +
+                        " Product : {3:20}" +
+                        " Version : {4:20}"
                     ).format(str(port), state, service, product, version)
                 )
 
                 if state == 'open':
                     HostArray.insert(len(HostArray), [target, port, service, product, version])
 
-    except:
-        print_colored("Target " + str(target) + " seems to have no open ports.", colors.red)
-        output.WriteToFile("Target " + str(target) + " seems to have no open ports.")
+    except KeyError:
+        print_colored("Target " + str(target) + " seems to be offline.", colors.red)
+        WriteToFile("Target " + str(target) + " seems to be offline.")
+    except Exception as e:
+        print_colored("An error occured while scanning " + str(target) + ".", colors.red)
+        WriteToFile("An error occured while scanning " + str(target) + ".")
+        print_colored(str(e), colors.red)
+        WriteToFile(str(e))
     return HostArray
