@@ -3,7 +3,7 @@ from modules.nvdlib.nvdlib import searchCPE, searchCVE, getCVE
 from textwrap import wrap
 from os import get_terminal_size
 from requests.exceptions import JSONDecodeError
-from modules.outfile import output
+from modules.outfile import WriteToFile
 
 #generate keywords to search for from the information gathered from the target
 def GenerateKeywords(HostArray):
@@ -40,16 +40,16 @@ def GenerateKeywords(HostArray):
 
 def SearchSploits(HostArray, apiKey):
     print_colored("\n" + "-" * 60, colors.red)
-    print_colored("\tPossible vulnerabilities for " + str(HostArray[0][0]), colors.red)
+    print_colored(("Possible vulnerabilities for " + str(HostArray[0][0])).center(60), colors.red)
     print_colored("-" * 60 + "\n", colors.red)
-    output.WriteToFile("Possible vulnerabilities for " + str(HostArray[0][0]))
+    WriteToFile("\nPossible vulnerabilities for " + str(HostArray[0][0]))
     keywords = GenerateKeywords(HostArray)
     if len(keywords) <= 0:
-        print_colored("Insufficient information for " + str(HostArray[0][0]), colors.yellow)
-        output.WriteToFile("Insufficient information for " + str(HostArray[0][0]))
+        print_colored(("Insufficient information for " + str(HostArray[0][0])).center(60), colors.yellow)
+        WriteToFile("Insufficient information for " + str(HostArray[0][0]))
     else:
         print("Searching vulnerability database for %s keyword(s)...\n" % (len(keywords)))
-        output.WriteToFile("Searching vulnerability database for %s keyword(s)..." % (len(keywords)))
+        WriteToFile("Searching vulnerability database for %s keyword(s)..." % (len(keywords)))
         for keyword in keywords:
             #https://github.com/vehemont/nvdlib
             #search the NIST vulnerabilities database for the generated keywords
@@ -74,7 +74,7 @@ def SearchSploits(HostArray, apiKey):
                 if len(TitleList) > 0:
                     ProductTitle = min(TitleList)
                     print_colored("\n\n┌─[ %s ]" % ProductTitle, colors.yellow)
-                    output.WriteToFile("\n\n┌─[ %s ]" % ProductTitle)
+                    WriteToFile("\n\n┌─[ %s ]" % ProductTitle)
 
                     if apiKey:
                         ApiResponseCVE = searchCVE(keyword = str(keyword), key = str(apiKey))
@@ -83,7 +83,7 @@ def SearchSploits(HostArray, apiKey):
                     
                     for CVE in ApiResponseCVE:
                         print("│\n├─────┤ " + bcolors.red + str(CVE.id) + bcolors.endc + "\n│")
-                        output.WriteToFile("│\n├─────┤ " + str(CVE.id) + "\n│")
+                        WriteToFile("│\n├─────┤ " + str(CVE.id) + "\n│")
 
                         try:
                             description = str(CVE.cve.description.description_data[0].value)
@@ -123,22 +123,22 @@ def SearchSploits(HostArray, apiKey):
                         wrapped_description = wrap(description, termsize.columns - 50)
 
                         print("│\t\t" + bcolors.cyan + "Description : " + bcolors.endc)
-                        output.WriteToFile("│\t\t" + "Description : ")
+                        WriteToFile("│\t\t" + "Description : ")
                         for line in wrapped_description:
                             print("│\t\t\t" + line)
-                            output.WriteToFile("│\t\t\t" + line)
+                            WriteToFile("│\t\t\t" + line)
                         print("│\t\t" + bcolors.cyan + "Severity : " + bcolors.endc + severity + " - " + score)
-                        output.WriteToFile("│\t\t" + "Severity : " + severity + " - " + score)
+                        WriteToFile("│\t\t" + "Severity : " + severity + " - " + score)
                         
                         print("│\t\t" + bcolors.cyan + "Exploitability : " + bcolors.endc + exploitability)
-                        output.WriteToFile("│\t\t" + "Exploitability : " + exploitability)
+                        WriteToFile("│\t\t" + "Exploitability : " + exploitability)
                         
                         print("│\t\t" + bcolors.cyan + "Details : " + bcolors.endc + details)
-                        output.WriteToFile("│\t\t" + "Details : " + details)
+                        WriteToFile("│\t\t" + "Details : " + details)
 
             except JSONDecodeError:
                 print_colored("An error occurred while trying to fetch details for " + str(keyword), colors.red)
-                output.WriteToFile("An error occurred while trying to fetch details for " + str(keyword))
+                WriteToFile("An error occurred while trying to fetch details for " + str(keyword))
             except KeyboardInterrupt:
                 print_colored("Skipping vulnerability detection for keyword " + str(keyword), colors.red)
-                output.WriteToFile("Skipped vulnerability detection for keyword " + str(keyword))
+                WriteToFile("Skipped vulnerability detection for keyword " + str(keyword))
